@@ -11,7 +11,7 @@ use warnings;
 
 package Dancer::Plugin::FlashMessage;
 BEGIN {
-  $Dancer::Plugin::FlashMessage::VERSION = '0.312';
+  $Dancer::Plugin::FlashMessage::VERSION = '0.313';
 }
 # ABSTRACT: Dancer plugin to display temporary messages, so called "flash messages".
 
@@ -22,9 +22,9 @@ use Dancer::Plugin;
 our $AUTHORITY = 'DAMS';
 
 my $conf = plugin_setting;
-
 my $token_name       = $conf->{token_name}       || 'flash';
 my $session_hash_key = $conf->{session_hash_key} || '_flash';
+
 my $session_engine;
 
 register flash => sub ($;$) {
@@ -33,7 +33,7 @@ register flash => sub ($;$) {
     $session_engine ||= engine 'session'
       or croak __PACKAGE__ . " error2 : there is no session engine configured in the configuration. You need a session engine to be able to use this plugin";
 
-    my $flash = session $session_hash_key || {};
+    my $flash = session($session_hash_key) || {};
     @_ == 2 and $flash->{$key} = $value;
     @_ == 1 and $value = delete $flash->{$key};
     session $session_hash_key, $flash;
@@ -43,12 +43,12 @@ register flash => sub ($;$) {
 before_template sub {
     shift->{$token_name} = {  map { my $key = $_; my $value;
                                     ( $key, sub { defined $value and return $value;
-                                                  my $flash = session $session_hash_key || {};
+                                                  my $flash = session($session_hash_key) || {};
                                                   $value = delete $flash->{$key};
                                                   session $session_hash_key, $flash;
                                                   return $value;
                                               } );
-                                } ( keys %{session $session_hash_key or {} })
+                                } ( keys %{session($session_hash_key) || {} })
                            };
 };
 
@@ -66,7 +66,7 @@ Dancer::Plugin::FlashMessage - Dancer plugin to display temporary messages, so c
 
 =head1 VERSION
 
-version 0.312
+version 0.313
 
 =head1 DESCRIPTION
 
